@@ -21,6 +21,8 @@ except NameError:
     def _next(o):
         return o.next()
 
+unicode_type = type(IS_PYTHON3 and 'abc' or 'abc'.decode('ASCII'))
+
 def _wait():
     # A crude wait/yield function not relying on synchronization primitives.
     time.sleep(0.01)
@@ -249,6 +251,19 @@ class TestLuaRuntime(SetupLuaRuntimeMixin, unittest.TestCase):
 
         self.assertEqual([[i]*len(table_values) for i in range(2,count+2)], l)
 
+    def test_iter_table_refcounting(self):
+        lua_func = self.lua.eval('''
+            function ()
+              local t = {}
+              t.foo = 'bar'
+              t.hello = 'world'
+              return t
+            end
+        ''')
+        table = lua_func()
+        for _ in range(10000):
+            list(table.items())
+
     def test_iter_table_mapping(self):
         keys = list('abcdefg')
         table = self.lua.eval('{%s}' % ','.join(['%s=%d' % (c,i) for i,c in enumerate(keys)]))
@@ -524,6 +539,47 @@ class TestLuaRuntime(SetupLuaRuntimeMixin, unittest.TestCase):
             raise ValueError("huhu")
         self.assertRaises(ValueError, function, test)
 
+    def test_attribute_filter(self):
+        def attr_filter(obj, name, setting):
+            if isinstance(name, unicode_type):
+                if not name.startswith('_'):
+                    return name + '1'
+            raise AttributeError('denied')
+
+        lua = lupa.LuaRuntime(attribute_filter=attr_filter)
+        function = lua.eval('function(obj) return obj.__name__ end')
+        class X(object):
+            a = 0
+            a1 = 1
+            _a = 2
+            __a = 3
+        x = X()
+
+        function = self.lua.eval('function(obj) return obj.a end')
+        self.assertEquals(function(x), 0)
+        function = lua.eval('function(obj) return obj.a end')
+        self.assertEquals(function(x), 1)
+
+        function = self.lua.eval('function(obj) return obj.__class__ end')
+        self.assertEquals(function(x), X)
+        function = lua.eval('function(obj) return obj.__class__ end')
+        self.assertRaises(AttributeError, function, x)
+
+        function = self.lua.eval('function(obj) return obj._a end')
+        self.assertEquals(function(x), 2)
+        function = lua.eval('function(obj) return obj._a end')
+        self.assertRaises(AttributeError, function, x)
+
+        function = self.lua.eval('function(obj) return obj._X__a end')
+        self.assertEquals(function(x), 3)
+        function = lua.eval('function(obj) return obj._X__a end')
+        self.assertRaises(AttributeError, function, x)
+
+        function = self.lua.eval('function(obj) return obj.a end')
+        self.assertEquals(function(x), 0)
+        function = lua.eval('function(obj) return obj.a end')
+        self.assertEquals(function(x), 1)
+
 
 class TestPythonObjectsInLua(SetupLuaRuntimeMixin, unittest.TestCase):
     def test_explicit_python_function(self):
@@ -926,8 +982,6 @@ class TestLuaRuntimeEncoding(unittest.TestCase):
     def tearDown(self):
         gc.collect()
 
-    unicode_type = type(IS_PYTHON3 and 'abc' or 'abc'.decode('ASCII'))
-
     test_string = '"abcüöä"'
     if not IS_PYTHON3:
         test_string = test_string.decode('UTF-8')
@@ -935,7 +989,7 @@ class TestLuaRuntimeEncoding(unittest.TestCase):
     def _encoding_test(self, encoding, expected_length):
         lua = lupa.LuaRuntime(encoding)
 
-        self.assertEqual(self.unicode_type,
+        self.assertEqual(unicode_type,
                          type(lua.eval(self.test_string)))
 
         self.assertEqual(self.test_string[1:-1],
